@@ -57,7 +57,7 @@ class Poisson(BaseDistribution):
 
     def loss(self, y, params):
         mu = self.predict(params)
-        return "PoissonError", -poisson.logpmf(y, mu=mu).mean()
+        return "Poisson-NLL", -poisson.logpmf(y, mu=mu).mean()
 
     def predict(self, params):
         log_mu = params
