@@ -7,9 +7,9 @@ def check_is_integer(x):
         raise ValueError("All values of target must be integers!")
 
 
-def check_is_positive(x):
+def check_is_ge_zero(x):
     if not all(x >= 0):
-        raise ValueError("All values of target must be positive!")
+        raise ValueError("All values of target must be >=0!")
 
 
 def check_is_gt_zero(x):
