@@ -1,12 +1,15 @@
 """XGBDistribution model
 """
-from typing import Callable
+import os
+from typing import Any, Callable, List, Optional, Tuple, Union, no_type_check
 
 import numpy as np
 from sklearn.base import RegressorMixin
 from sklearn.utils.validation import check_is_fitted
 from xgboost import config_context
-from xgboost.core import DMatrix
+from xgboost._typing import ArrayLike
+from xgboost.callback import TrainingCallback
+from xgboost.core import Booster, DMatrix, _deprecate_positional_args
 from xgboost.sklearn import XGBModel, _wrap_evaluation_matrices, xgboost_model_doc
 from xgboost.training import train
 
@@ -22,9 +25,14 @@ from xgboost_distribution.distributions import get_distribution, get_distributio
         Whether or not natural gradients should be used.""",
 )
 class XGBDistribution(XGBModel, RegressorMixin):
+    @_deprecate_positional_args
     def __init__(
-        self, distribution=None, natural_gradient=True, objective=None, **kwargs
-    ):
+        self,
+        distribution: str = None,
+        natural_gradient: bool = True,
+        objective: str = None,
+        **kwargs: Any,
+    ) -> None:
         self.distribution = distribution or "normal"
         self.natural_gradient = natural_gradient
 
@@ -35,20 +43,21 @@ class XGBDistribution(XGBModel, RegressorMixin):
 
         super().__init__(objective=None, **kwargs)
 
+    @_deprecate_positional_args
     def fit(
         self,
-        X,
-        y,
+        X: ArrayLike,
+        y: ArrayLike,
         *,
-        sample_weight=None,
-        eval_set=None,
-        early_stopping_rounds=None,
-        verbose=False,
-        xgb_model=None,
-        sample_weight_eval_set=None,
-        feature_weights=None,
-        callbacks=None,
-    ):
+        sample_weight: Optional[ArrayLike] = None,
+        eval_set: Optional[List[Tuple[ArrayLike, ArrayLike]]] = None,
+        early_stopping_rounds: Optional[int] = None,
+        verbose: Optional[bool] = False,
+        xgb_model: Optional[Union[Booster, str, XGBModel]] = None,
+        sample_weight_eval_set: Optional[List[ArrayLike]] = None,
+        feature_weights: Optional[ArrayLike] = None,
+        callbacks: Optional[List[TrainingCallback]] = None,
+    ) -> "XGBDistribution":
         """Fit gradient boosting distribution model.
 
         Note that calling ``fit()`` multiple times will cause the model object to be
@@ -57,51 +66,37 @@ class XGBDistribution(XGBModel, RegressorMixin):
 
         Parameters
         ----------
-        X : array_like
+        X :
             Feature matrix
-        y : array_like
+        y :
             Labels
-        sample_weight : array_like
+        sample_weight :
             instance weights
-        eval_set : list
+        eval_set :
             A list of (X, y) tuple pairs to use as validation sets, for which
             metrics will be computed.
             Validation metrics will help us track the performance of the model.
         early_stopping_rounds : int
-            Activates early stopping. Validation metric needs to improve at least once
-            in every **early_stopping_rounds** round(s) to continue training.
-            Requires at least one item in **eval_set**.
-
-            The method returns the model from the last iteration (not the best one).
-            If there's more than one item in **eval_set**, the last entry will be used
-            for early stopping.
-
-            If early stopping occurs, the model will have three additional fields:
-            ``clf.best_score``, ``clf.best_iteration``.
-        verbose : bool
+            .. deprecated:: 1.6.0
+                Use `early_stopping_rounds` in :py:meth:`__init__` or
+                :py:meth:`set_params` instead.
+        verbose :
             If `verbose` and an evaluation set is used, writes the evaluation metric
             measured on the validation set to stderr.
-        xgb_model : `xgboost.core.Booster`, `xgboost.sklearn.XGBModel`
+        xgb_model :
             file name of stored XGBoost model or 'Booster' instance XGBoost model to be
             loaded before training (allows training continuation).
-        sample_weight_eval_set : array_like
+        sample_weight_eval_set :
             A list of the form [L_1, L_2, ..., L_n], where each L_i is an array like
             object storing instance weights for the i-th validation set.
-        feature_weights : array_like
+        feature_weights :
             Weight for each feature, defines the probability of each feature being
             selected when colsample is being used.  All values must be greater than 0,
-            otherwise a `ValueError` is thrown.  Only available for `hist`, `gpu_hist`
-            and `exact` tree methods.
-        callbacks : list
-            List of callback functions that are applied at end of each iteration.
-            It is possible to use predefined callbacks by using :ref:`callback_api`.
-            Example:
-
-            .. code-block:: python
-
-                callbacks = [xgb.callback.EarlyStopping(rounds=early_stopping_rounds,
-                                                        save_best=True)]
+            otherwise a `ValueError` is thrown.
 
+        callbacks :
+            .. deprecated:: 1.6.0
+                Use `callbacks` in :py:meth:`__init__` or :py:meth:`set_params` instead.
         """
         self._distribution = get_distribution(self.distribution)
         self._distribution.check_target(y)
@@ -118,12 +113,18 @@ class XGBDistribution(XGBModel, RegressorMixin):
 
         base_margin = self._get_base_margin(len(y))
         if eval_set is not None:
-            base_margin_eval_set = [
+            base_margin_eval_set: Optional[List[np.ndarray]] = [
                 self._get_base_margin(len(evals[1])) for evals in eval_set
             ]
         else:
             base_margin_eval_set = None
 
+        for param in [sample_weight, sample_weight_eval_set]:
+            if param is not None:
+                raise NotImplementedError(
+                    "Sample weights are currently not supported by XGBDistribution!"
+                )
+
         train_dmatrix, evals = _wrap_evaluation_matrices(
             missing=self.missing,
             X=X,
@@ -139,11 +140,18 @@ class XGBDistribution(XGBModel, RegressorMixin):
             eval_group=None,
             eval_qid=None,
             create_dmatrix=lambda **kwargs: DMatrix(nthread=self.n_jobs, **kwargs),
-            label_transform=lambda x: x,
+            enable_categorical=self.enable_categorical,
         )
 
-        evals_result = {}
-        model, _, params = self._configure_fit(xgb_model, None, params)
+        evals_result: TrainingCallback.EvalsLog = {}
+
+        model, _, params, early_stopping_rounds, callbacks = self._configure_fit(
+            booster=xgb_model,
+            eval_metric=None,
+            params=params,
+            early_stopping_rounds=early_stopping_rounds,
+            callbacks=callbacks,
+        )
 
         # Suppress warnings from unexpected distribution & natural_gradient params
         with config_context(verbosity=0):
@@ -155,7 +163,7 @@ class XGBDistribution(XGBModel, RegressorMixin):
                 early_stopping_rounds=early_stopping_rounds,
                 evals_result=evals_result,
                 obj=self._objective_func(),
-                feval=self._evaluation_func(),
+                custom_metric=self._evaluation_func(),
                 verbose_eval=verbose,
                 xgb_model=model,
                 callbacks=callbacks,
@@ -166,18 +174,19 @@ class XGBDistribution(XGBModel, RegressorMixin):
 
         return self
 
+    @no_type_check
     def predict(
         self,
-        X,
-        ntree_limit=None,
-        validate_features=False,
-        iteration_range=None,
-    ):
+        X: ArrayLike,
+        ntree_limit: Optional[int] = None,
+        validate_features: bool = True,
+        iteration_range: Optional[Tuple[int, int]] = None,
+    ) -> Tuple[np.ndarray]:
         """Predict all params of distribution of each `X` example.
 
         Parameters
         ----------
-        X : array_like
+        X : ArrayLike
             Feature matrix.
         ntree_limit : int
             Deprecated, use `iteration_range` instead.
@@ -210,7 +219,7 @@ class XGBDistribution(XGBModel, RegressorMixin):
         )
         return self._distribution.predict(params)
 
-    def save_model(self, fname) -> None:
+    def save_model(self, fname: Union[str, os.PathLike]) -> None:
         # self._distribution class cannot be saved by `super().save_model`, as it
         # attempts to call `json.dumps({"_distribution": self._distribution})`
         # Hence we delete, and then reinstantiate
@@ -219,13 +228,15 @@ class XGBDistribution(XGBModel, RegressorMixin):
         super().save_model(fname)
         self._distribution = get_distribution(self.distribution)
 
-    def load_model(self, fname) -> None:
+    def load_model(self, fname: Union[str, bytearray, os.PathLike]) -> None:
         super().load_model(fname)
         # See above: Currently need to reinstantiate distribution post loading
         self._distribution = get_distribution(self.distribution)
 
-    def _objective_func(self) -> Callable:
-        def obj(params: np.ndarray, data: DMatrix):
+    def _objective_func(
+        self,
+    ) -> Callable[[np.ndarray, DMatrix], Tuple[np.ndarray, np.ndarray]]:
+        def obj(params: np.ndarray, data: DMatrix) -> Tuple[np.ndarray, np.ndarray]:
             y = data.get_label()
             grad, hess = self._distribution.gradient_and_hessian(
                 y=y, params=params, natural_gradient=self.natural_gradient
@@ -234,14 +245,12 @@ class XGBDistribution(XGBModel, RegressorMixin):
 
         return obj
 
-    def _evaluation_func(self) -> Callable:
-        def feval(params: np.ndarray, data: DMatrix):
+    def _evaluation_func(self) -> Callable[[np.ndarray, DMatrix], Tuple[str, float]]:
+        def feval(params: np.ndarray, data: DMatrix) -> Tuple[str, float]:
             y = data.get_label()
             return self._distribution.loss(y=y, params=params)
 
         return feval
 
-    def _get_base_margin(self, n_samples):
-        return (
-            np.ones(shape=(n_samples, 1)) * np.array(self._starting_params)
-        ).flatten()
+    def _get_base_margin(self, n_samples: int) -> np.ndarray:
+        return np.ones(shape=(n_samples, 1)) * np.array(self._starting_params)
