@@ -4,9 +4,9 @@ import numpy as np
 import pandas as pd
 
 from xgboost_distribution.distributions.utils import (
+    check_is_ge_zero,
     check_is_gt_zero,
     check_is_integer,
-    check_is_positive,
 )
 
 
@@ -31,17 +31,17 @@ def test_check_is_integer_raises(x):
     "x",
     [np.array([0, 1]), pd.Series([0, 1.2, 2])],
 )
-def test_check_is_positive(x):
-    check_is_positive(x)
+def test_check_is_ge_zero(x):
+    check_is_ge_zero(x)
 
 
 @pytest.mark.parametrize(
     "x",
     [np.array([-0.1, 1.2]), pd.Series([-1.1, 0.4, 2.3])],
 )
-def test_check_is_positive_raises(x):
+def test_check_is_ge_zero_raises(x):
     with pytest.raises(ValueError):
-        check_is_positive(x)
+        check_is_ge_zero(x)
 
 
 @pytest.mark.parametrize(
